==> qt-creator-opensource-src-3.0.0.zip: qt-creator-opensource-src-3.0.0/src/plugins/qmlprofiler/qmlprofilerengine.h <==
/****************************************************************************
**
** Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
** Contact: http://www.qt-project.org/legal
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Digia.  For licensing terms and
** conditions see http://qt.digia.com/licensing.  For further information
** use the contact form at http://qt.digia.com/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Digia gives you certain additional
** rights.  These rights are described in the Digia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
****************************************************************************/

#ifndef QMLPROFILERENGINE_H
#define QMLPROFILERENGINE_H

#include "qmlprofilerstatemanager.h"

#include <analyzerbase/analyzerruncontrol.h>
#include <utils/outputformat.h>

namespace QmlProfiler {
namespace Internal {

class QmlProfilerRunControl : public Analyzer::AnalyzerRunControl
{
    Q_OBJECT

public:
    QmlProfilerRunControl(const Analyzer::AnalyzerStartParameters &sp,
                      ProjectExplorer::RunConfiguration *runConfiguration);
    ~QmlProfilerRunControl();

    void registerProfilerStateManager( QmlProfilerStateManager *profilerState );

    static void showNonmodalWarning(const QString &warningMsg);

    void notifyRemoteSetupDone(quint16 port);

signals:
    void processRunning(quint16 port);
    void timeUpdate();

public slots:
    bool startEngine();
    void stopEngine();

private slots:
    void notifyRemoteFinished(bool success = true);

    void cancelProcess();
    void logApplicationMessage(const QString &msg, Utils::OutputFormat format);
    void wrongSetupMessageBox(const QString &errorMessage);
    void wrongSetupMessageBoxFinished(int);
    void processIsRunning(quint16 port = 0);
    void engineStarted();
    void runControlFinished();

private slots:
    void profilerStateChanged();

private:
    class QmlProfilerEnginePrivate;
    QmlProfilerEnginePrivate *d;
};

} // namespace Internal
} // namespace QmlProfiler

#endif // QMLPROFILERENGINE_H

==> qt-creator-opensource-src-3.1.2.zip: qt-creator-opensource-src-3.1.2/src/plugins/qmlprofiler/qmlprofilerengine.h <==
/****************************************************************************
**
** Copyright (C) 2014 Digia Plc and/or its subsidiary(-ies).
** Contact: http://www.qt-project.org/legal
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Digia.  For licensing terms and
** conditions see http://qt.digia.com/licensing.  For further information
** use the contact form at http://qt.digia.com/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Digia gives you certain additional
** rights.  These rights are described in the Digia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
****************************************************************************/

#ifndef QMLPROFILERENGINE_H
#define QMLPROFILERENGINE_H

#include "qmlprofilerstatemanager.h"

#include <analyzerbase/analyzerruncontrol.h>
#include <utils/outputformat.h>

namespace QmlProfiler {
namespace Internal {

class QmlProfilerRunControl : public Analyzer::AnalyzerRunControl
{
    Q_OBJECT

public:
    QmlProfilerRunControl(const Analyzer::AnalyzerStartParameters &sp,
                      ProjectExplorer::RunConfiguration *runConfiguration);
    ~QmlProfilerRunControl();

    void registerProfilerStateManager( QmlProfilerStateManager *profilerState );

    static void showNonmodalWarning(const QString &warningMsg);

    void notifyRemoteSetupDone(quint16 port);

signals:
    void processRunning(quint16 port);
    void timeUpdate();

public slots:
    bool startEngine();
    void stopEngine();

private slots:
    void notifyRemoteFinished();

    void cancelProcess();
    void logApplicationMessage(const QString &msg, Utils::OutputFormat format);
    void wrongSetupMessageBox(const QString &errorMessage);
    void wrongSetupMessageBoxFinished(int);
    void processIsRunning(quint16 port = 0);
    void engineStarted();
    void runControlFinished();

private slots:
    void profilerStateChanged();

private:
    class QmlProfilerEnginePrivate;
    QmlProfilerEnginePrivate *d;
};

} // namespace Internal
} // namespace QmlProfiler

#endif // QMLPROFILERENGINE_H
